envutil

package
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 22, 2024 License: GPL-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FromEnvironment

func FromEnvironment(env []string) (map[string]string, error)

FromEnvironment consumes the environment and outputs a valid input data field into the supplied map.

Types

type EnvironmentVariablesError

type EnvironmentVariablesError struct {
	Reason    string
	RawEnvVar string
}

EnvironmentVariablesError is raised when an environment variable is improperly formatted.

func (EnvironmentVariablesError) Error

func (eev EnvironmentVariablesError) Error() string

Error implements error.

Jump to